@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        demo/Printing.pm
+## Name:        Printing.pm
 ## Purpose:     Printing demo
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     12/09/2001
-## RCS-ID:      $Id: Printing.pm,v 1.6 2005/03/15 21:35:23 mbarbon Exp $
-## Copyright:   (c) 2001, 2003 Mattia Barbon
+## Created:     12/ 9/2001
+## RCS-ID:      
+## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -67,7 +67,6 @@ sub new {
   $this->{CANVAS} = $canvas;
 
   EVT_BUTTON( $this, $preview, \&OnPreview );
-  EVT_BUTTON( $this, $print, \&OnPrint );
 
   return $this;
 }
@@ -82,57 +81,12 @@ sub OnPreview {
   my $prev = PrintingDemoPrintout->new( $this->canvas, "Preview" );
   my $print = PrintingDemoPrintout->new( $this->canvas, "Print" );
   my $preview = Wx::PrintPreview->new( $prev, $print );
-  my $frame = PrintingDemoPreviewFrame->new( $preview, wxTheApp->GetTopWindow,
-                                     "Printing Demo Preview", [-1, -1], [600, -1] );
+  my $frame = Wx::PreviewFrame->new( $preview, wxTheApp->GetTopWindow,
+                                     "Printing Demo Preview" );
   $frame->Initialize();
-
   $frame->Show( 1 );
 }
 
-sub OnPrint {
-  my( $this, $event ) = @_;
-
-  my $printer = Wx::Printer->new;
-  my $printout = PrintingDemoPrintout->new( $this->canvas, "Print" );
-  $printer->Print( $this, $printout, 1 );
-
-  $printout->Destroy;
-}
-
-package PrintingDemoPreviewFrame;
-
-use base 'Wx::PlPreviewFrame';
-
-sub Initialize {
-    Wx::LogMessage( 'PrintingDemoPreviewFrame::Initialize' );
-
-    $_[0]->SUPER::Initialize;
-}
-
-sub CreateControlBar {
-    Wx::LogMessage( 'PrintingDemoPreviewFrame::CreateControlBar' );
-
-    $_[0]->SetPreviewControlBar
-      ( PrintingDemoControlBar->new( $_[0]->GetPrintPreview, $_[0] ) );
-    $_[0]->GetPreviewControlBar->CreateButtons;
-}
-
-package PrintingDemoControlBar;
-
-use base 'Wx::PlPreviewControlBar';
-
-sub new {
-    Wx::LogMessage( 'PrintingDemoControlBar::new' );
-
-    $_[0]->SUPER::new( $_[1], 0xffffffff, $_[2], [0, 0], [400, 40] );
-}
-
-sub CreateButtons {
-    Wx::LogMessage( 'PrintingDemoControlBar::CreateButtons' );
-
-    shift->SUPER::CreateButtons;
-}
-
 package PrintingDemoPrintout;
 
 use strict;
@@ -258,9 +212,9 @@ use Wx qw(:colour :pen);
 sub OnDraw {
   my $this = shift;
   my $dc = shift;
-#  my $font = Wx::Font->new( 20, wxSCRIPT, wxSLANT, wxBOLD );
+  my $font = Wx::Font->new( 30, wxSCRIPT, wxSLANT, wxBOLD );
 
-#  $dc->SetFont( $font );
+  $dc->SetFont( $font );
   $dc->DrawRotatedText( "Draw Here", 200, 200, 35 );
 
   $dc->DrawEllipse( 20, 20, 50, 50 );
@@ -269,17 +223,8 @@ sub OnDraw {
   $dc->DrawEllipse( $x_size - 50 - 20, $y_size - 50 - 20, 50, 50 );
 
   $dc->SetPen( Wx::Pen->new( wxRED, 5, 0 ) );
-  # wxGTK does not like DrawLines in this context
   foreach my $i ( @{$this->{LINES}} ) {
-    my $prev;
-
-    foreach my $j ( @$i ) {
-      if( $j != ${$i}[0] ) {
-        $dc->DrawLine( @$prev, @$j );
-#       $dc->DrawLines( $i );
-      }
-      $prev = $j;
-    }
+    $dc->DrawLines( $i );
   }
 }
 
