@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        demo/wxClipboard.pm
+## Name:        wxClipboard.pm
 ## Purpose:     Clipboard demo
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     12/09/2001
-## RCS-ID:      $Id: wxClipboard.pm,v 1.8 2006/03/17 05:45:21 netcon Exp $
-## Copyright:   (c) 2001, 2003 Mattia Barbon
+## Created:     12/ 9/2001
+## RCS-ID:      
+## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -20,32 +20,18 @@ sub window {
   shift;
   my $parent = shift;
 
-  Wx::InitAllImageHandlers; # for wxGTK
   return ClipboardDemoWindow->new( $parent );
 }
 
 sub description {
     return <<EOT;
-<html>
-<head>
-  <title>Wx::Clipboard</title>
-</head>
-<body>
-<h3>Wx::Clipboard</h3>
-
-<p>
-  This class is used to interact with the system clipboard.
-</p>
-
-</body>
-</html>
 EOT
 }
 
 package ClipboardDemoWindow;
 
 use strict;
-use Wx qw(wxTheClipboard wxNullBitmap);
+use Wx qw(wxTheClipboard);
 use Wx::Event qw(EVT_BUTTON);
 require DataObjects;
 
@@ -60,6 +46,7 @@ sub new {
   my $copy = Wx::Button->new( $this, -1, 'Copy Text', [ 20, 20 ] );
   my $paste = Wx::Button->new( $this, -1, 'Paste', [ 120, 20 ] );
   my $copy_im = Wx::Button->new( $this, -1, 'Copy Image', [ 20, 50 ] );
+  my $copy_both = Wx::Button->new( $this, -1, 'Copy Both', [ 20, 80 ] );
 
   $this->{TEXT} = Wx::StaticText->new( $this, -1, '', [ 220, 20 ] );
   $this->{IMAGE} = Wx::StaticBitmap->new( $this, -1, wxNullBitmap,
@@ -68,18 +55,8 @@ sub new {
   EVT_BUTTON( $this, $copy, \&OnCopyText );
   EVT_BUTTON( $this, $paste, \&OnPaste );
   EVT_BUTTON( $this, $copy_im, \&OnCopyImage );
-
-  # unfortunately pasting a composite data object segfaults
-  # on wx 2.2/wxGTK
-  my $copy_both = Wx::Button->new( $this, -1, 'Copy Both', [ 20, 80 ] );
   EVT_BUTTON( $this, $copy_both, \&OnCopyBoth );
 
-  # this does NOT work on WinXP
-  my $copy_pd = Wx::Button->new( $this, -1, 'Copy Data', [ 20, 110 ] );
-  EVT_BUTTON( $this, $copy_pd, \&OnCopyData );
-
-  # wxTheClipboard->UsePrimarySelection( 0 );
-
   return $this;
 }
 
@@ -118,14 +95,6 @@ sub OnCopyBoth {
   Wx::LogMessage( "Copied both text and image" );
 }
 
-sub OnCopyData {
-  my( $this, $event ) = @_;
-  my $PerlData = { fruit => 'lemon', colour => 'yellow' };
-  my $data = MyPerlDataObject->new( $PerlData );
-  _Copy( $data );
-  Wx::LogMessage( "Copied perl data object: fruit=$PerlData->{fruit}, colour=$PerlData->{colour}" );
-}
-
 sub OnPaste {
   my( $this, $event ) = @_;
 
@@ -134,50 +103,21 @@ sub OnPaste {
   my $text = '';
   if( wxTheClipboard->IsSupported( wxDF_TEXT ) ) {
     my $data = Wx::TextDataObject->new;
-    my $ok = wxTheClipboard->GetData( $data );
-    if( $ok ) {
-      Wx::LogMessage( "Pasted text data" );
-      $text = $data->GetText;
-    } else {
-      Wx::LogMessage( "Error pasting text data" );
-      $text = '';
-    }
+    wxTheClipboard->GetData( $data );
+    Wx::LogMessage( "Pasted text data" );
+    $text = $data->GetText;
   }
   $this->text->SetLabel( $text );
 
   my $bitmap = wxNullBitmap;
   if( wxTheClipboard->IsSupported( wxDF_BITMAP ) ) {
     my $data = Wx::BitmapDataObject->new;
-    my $ok = wxTheClipboard->GetData( $data );
-    if( $ok ) {
-      Wx::LogMessage( "Pasted bitmap data" );
-      $bitmap =  $data->GetBitmap;
-    } else {
-      Wx::LogMessage( "Error pasting bitmap data" );
-      $bitmap = wxNullBitmap;
-    }
+    wxTheClipboard->GetData( $data );
+    Wx::LogMessage( "Pasted bitmap data" );
+    $bitmap =  $data->GetBitmap;
   }
   $this->image->SetBitmap( $bitmap );
 
-  # testing the perl data object
-  my $data = MyPerlDataObject->new();
-  Wx::LogMessage( "Testing if clipboard supports: " . $data->GetFormat->GetId() );
-  if( wxTheClipboard->IsSupported( $data->GetFormat ) ) {
-	Wx::LogMessage( "It does: get data from clipboard" );
-	my $ok = wxTheClipboard->GetData( $data );
-	if( $ok ) {
-	  Wx::LogMessage( "Pasted perl data object" );
-	  my $PerlData = $data->GetPerlData();
-	  foreach (keys %$PerlData) {
-		  $text .= "$_ = $PerlData->{$_} ";
-	  }
-	} else {
-	  Wx::LogMessage( "Error pasting perl data object" );
-	  $text = '';
-	}
-    $this->text->SetLabel( $text );
-  }
-
   wxTheClipboard->Close;
 }
 
