@@ -1,10 +1,10 @@
 #############################################################################
-## Name:        demo/wxFileSystem.pm
+## Name:        wxFileSystem.pm
 ## Purpose:     wxFileSystem demo
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     12/09/2001
-## RCS-ID:      $Id: wxFileSystem.pm,v 1.3 2004/10/19 20:28:06 mbarbon Exp $
+## Created:     12/ 9/2001
+## RCS-ID:      
 ## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -70,7 +70,7 @@ sub description {
   <title>wxFileSystem</title>
 </head>
 <body>
-<h3>Wx::FileSystem, Wx::FSFile, Wx::FileSystemHandler</h3>
+<h3>wxFileSystem, wxFSFile, wxFileSystemHandler</h3>
 
 <p>
   these classes let you access various kinds of filesystem-like
