@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        demo/wxHtmlWindow.pm
+## Name:        wxHtmlWindow.pm
 ## Purpose:     wxHtmlWindow demo
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     12/09/2001
-## RCS-ID:      $Id: wxHtmlWindow.pm,v 1.4 2004/12/21 21:12:46 mbarbon Exp $
-## Copyright:   (c) 2001, 2004 Mattia Barbon
+## Created:     12/ 9/2001
+## RCS-ID:      
+## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -25,14 +25,14 @@ sub description {
   return <<EOT;
 <html>
 <head>
-  <title>Wx::HtmlWindow</title>
+  <title>wxHtmlWindow</title>
 </head>
 <body>
-<h3>Wx::HtmlWindow</h3>
+<h3>wxHtmlWindow</h3>
 
 <p>
   wxHTML is an HTML rendering engine written entirely
-  using wxWidgets.
+  using wxWindows.
 </p>
 
 </body>
