@@ -10,20 +10,25 @@
 ##              modify it under the same terms as Perl itself
 #############################################################################
 
+package Wx::Size;
+
+no strict;
+
+*y = \&Wx::Size::height;
+*x = \&Wx::Size::width;
+
 package Wx::Region;
 
 use strict;
 use Carp;
 
-*Wx::Size::y = \&Wx::Size::height;
-*Wx::Size::x = \&Wx::Size::width;
-
 sub new {
   shift;
 
   Wx::_match( @_, $Wx::_n_n_n_n, 4 )   && return Wx::Region::newXYWH( @_ );
   Wx::_match( @_, $Wx::_wpoi_wpoi, 2 ) && return Wx::Region::newPP( @_ );
   Wx::_match( @_, $Wx::_wrec, 1 )      && return Wx::Region::newRect( @_ );
+  Wx::_match( @_, $Wx::_arr, 1, 1 )    && return Wx::Region::newPolygon( @_ );
   croak Wx::_ovl_error;
 }
 
